summaryrefslogtreecommitdiffstats
path: root/kwin/clients/quartz/quartz.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /kwin/clients/quartz/quartz.cpp
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kwin/clients/quartz/quartz.cpp')
-rw-r--r--kwin/clients/quartz/quartz.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kwin/clients/quartz/quartz.cpp b/kwin/clients/quartz/quartz.cpp
index 82caabb45..489ccd081 100644
--- a/kwin/clients/quartz/quartz.cpp
+++ b/kwin/clients/quartz/quartz.cpp
@@ -207,7 +207,7 @@ void QuartzHandler::readConfig()
extraSlim = conf.readBoolEntry( "UseQuartzExtraSlim", false );
// A small hack to make the on all desktops button look nicer
- onAllDesktopsButtonOnLeft = KDecoration::options()->titleButtonsLeft().contains( 'S' );
+ onAllDesktopsButtonOnLeft = KDecoration::options()->titleButtonsLeft().tqcontains( 'S' );
if ( TQApplication::reverseLayout() )
onAllDesktopsButtonOnLeft = !onAllDesktopsButtonOnLeft;
switch(options()->preferredBorderSize(this)) {
@@ -291,18 +291,18 @@ void QuartzHandler::drawBlocks( KPixmap *pi, KPixmap &p, const TQColor &c1, cons
void QuartzHandler::createPixmaps()
{
// Obtain titlebar blend colours, and create the block stuff on pixmaps.
- TQColorGroup g2 = options()->colorGroup(ColorTitleBlend, true);
+ TQColorGroup g2 = options()->tqcolorGroup(ColorTitleBlend, true);
TQColor c2 = g2.background();
- g2 = options()->colorGroup(ColorTitleBar, true );
+ g2 = options()->tqcolorGroup(ColorTitleBar, true );
TQColor c = g2.background().light(130);
titleBlocks = new KPixmap();
titleBlocks->resize( normalTitleHeight*25/18, normalTitleHeight );
drawBlocks( titleBlocks, *titleBlocks, c, c2 );
- g2 = options()->colorGroup(ColorTitleBlend, false);
+ g2 = options()->tqcolorGroup(ColorTitleBlend, false);
c2 = g2.background();
- g2 = options()->colorGroup(ColorTitleBar, false );
+ g2 = options()->tqcolorGroup(ColorTitleBar, false );
c = g2.background().light(130);
ititleBlocks = new KPixmap();
@@ -313,9 +313,9 @@ void QuartzHandler::createPixmaps()
TQColorGroup g;
TQPainter p;
- g = options()->colorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, true );
+ g = options()->tqcolorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, true );
c = onAllDesktopsButtonOnLeft ? g.background().light(130) : g.background();
- g2 = options()->colorGroup( ColorButtonBg, true );
+ g2 = options()->tqcolorGroup( ColorButtonBg, true );
pinUpPix = new KPixmap();
pinUpPix->resize(16, 16);
@@ -335,9 +335,9 @@ void QuartzHandler::createPixmaps()
// Inactive pins
- g = options()->colorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, false );
+ g = options()->tqcolorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, false );
c = onAllDesktopsButtonOnLeft ? g.background().light(130) : g.background();
- g2 = options()->colorGroup( ColorButtonBg, false );
+ g2 = options()->tqcolorGroup( ColorButtonBg, false );
ipinUpPix = new KPixmap();
ipinUpPix->resize(16, 16);
@@ -437,7 +437,7 @@ void QuartzButton::setBitmap(const unsigned char *bitmap)
if (bitmap) {
deco = new TQBitmap(10, 10, bitmap, true);
deco->setMask( *deco );
- repaint( false );
+ tqrepaint( false );
}
}
@@ -540,7 +540,7 @@ bool QuartzClient::decorationBehaviour(DecorationBehaviour behaviour) const
}
}
-int QuartzClient::layoutMetric(LayoutMetric lm, bool respectWindowState, const KCommonDecorationButton *btn) const
+int QuartzClient::tqlayoutMetric(LayoutMetric lm, bool respectWindowState, const KCommonDecorationButton *btn) const
{
bool maximized = maximizeMode()==MaximizeFull && !options()->moveResizeMaximizedWindows();
@@ -582,7 +582,7 @@ int QuartzClient::layoutMetric(LayoutMetric lm, bool respectWindowState, const K
return 3;
default:
- return KCommonDecoration::layoutMetric(lm, respectWindowState, btn);
+ return KCommonDecoration::tqlayoutMetric(lm, respectWindowState, btn);
}
}
@@ -643,8 +643,8 @@ void QuartzClient::reset( unsigned long changed )
{
if (changed & SettingColors || changed & SettingFont)
{
- // repaint the whole thing
- widget()->repaint(false);
+ // tqrepaint the whole thing
+ widget()->tqrepaint(false);
}
KCommonDecoration::reset(changed);
@@ -675,9 +675,9 @@ void QuartzClient::paintEvent( TQPaintEvent* )
// Draw part of the frame that is the title color
if( coloredFrame )
- g = options()->colorGroup(ColorTitleBar, isActive());
+ g = options()->tqcolorGroup(ColorTitleBar, isActive());
else
- g = options()->colorGroup(ColorFrame, isActive());
+ g = options()->tqcolorGroup(ColorFrame, isActive());
// Draw outer highlights and lowlights
p.setPen( g.light().light(120) );
@@ -724,11 +724,11 @@ void QuartzClient::paintEvent( TQPaintEvent* )
// ===================
int r_x, r_y, r_x2, r_y2;
widget()->rect().coords(&r_x, &r_y, &r_x2, &r_y2);
- const int titleEdgeLeft = layoutMetric(LM_TitleEdgeLeft);
- const int titleEdgeTop = layoutMetric(LM_TitleEdgeTop);
- const int titleEdgeRight = layoutMetric(LM_TitleEdgeRight);
- const int titleEdgeBottom = layoutMetric(LM_TitleEdgeBottom);
- const int ttlHeight = layoutMetric(LM_TitleHeight);
+ const int titleEdgeLeft = tqlayoutMetric(LM_TitleEdgeLeft);
+ const int titleEdgeTop = tqlayoutMetric(LM_TitleEdgeTop);
+ const int titleEdgeRight = tqlayoutMetric(LM_TitleEdgeRight);
+ const int titleEdgeBottom = tqlayoutMetric(LM_TitleEdgeBottom);
+ const int ttlHeight = tqlayoutMetric(LM_TitleHeight);
const int titleEdgeBottomBottom = r_y+titleEdgeTop+ttlHeight+titleEdgeBottom-1;
r = TQRect(r_x+titleEdgeLeft+buttonsLeftWidth(), r_y+titleEdgeTop,
r_x2-titleEdgeRight-buttonsRightWidth()-(r_x+titleEdgeLeft+buttonsLeftWidth()),